==> haskell-juicypixels-3.3.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.3.1
id: JuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
key: JuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
license: BSD-3-Clause
maintainer: vincent.berthoux@gmail.com
author: Vincent Berthoux
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
abi: 76ae9cd77938ceb75dbc084e47aef5ec
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
import-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/JuicyPixels-3.3.1
hs-libraries: HSJuicyPixels-3.3.1-GoHpnhcfmT4HnjNPbV3sCn
include-dirs: /usr/lib/ghc-8.4.3/site-local/JuicyPixels-3.3.1/include
depends:
    base-4.11.1.0 bytestring-0.10.8.2 mtl-2.2.2 binary-0.8.5.1
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH transformers-0.5.5.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc deepseq-1.4.3.0
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=8fa648805d93281f19b98bbf203b4b1c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.3.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-juicypixels.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.3.2
id: JuicyPixels-3.3.2-98nCIHoiETt1g4NtZC29ex
key: JuicyPixels-3.3.2-98nCIHoiETt1g4NtZC29ex
license: BSD-3-Clause
maintainer: vincent.berthoux@gmail.com
author: Vincent Berthoux
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
abi: f2ac89cf05053b94b7478f68f3b3a205
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.ColorQuant
    Codec.Picture.Gif Codec.Picture.HDR Codec.Picture.Jpg
    Codec.Picture.Metadata Codec.Picture.Metadata.Exif
    Codec.Picture.Png Codec.Picture.Saving Codec.Picture.Tga
    Codec.Picture.Tiff Codec.Picture.Types
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
import-dirs: /usr/lib/ghc-8.6.1/site-local/JuicyPixels-3.3.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/JuicyPixels-3.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/JuicyPixels-3.3.2
hs-libraries: HSJuicyPixels-3.3.2-98nCIHoiETt1g4NtZC29ex
include-dirs: /usr/lib/ghc-8.6.1/site-local/JuicyPixels-3.3.2/include
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 mtl-2.2.2 primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    transformers-0.5.5.0 vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
